==> connector-service-1.0.0-20190719.091809-30-sources.jar: com/bizvane/connectorservice/entity/common/OrderRefundRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

import java.util.Date;

/**
 * @author liuying
 * @date 2018/8/17
 * @description
 */

public class OrderRefundRequestVO extends BaseModel{

    /**
     * 订单编号
     */
    private String orderNo;

    /**
     * 会员卡号(线下会员卡号)
     */
    private String erpCardNo;

    /**
     * 会员id(线下会员id)
     */
    private String erpId;

    /**
     * 审核时间(格式：yyyy-MM-dd HH:mm:ss)
     */
    private Date refundDate;

    /**
     * 退款单号
     */
    private String refundNo;

    /**
     * 退款金额
     */
    private Double refundMoney;

    /**
     * 退款备注
     */
    private String redundRemark;

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getErpCardNo() {
        return erpCardNo;
    }

    public void setErpCardNo(String erpCardNo) {
        this.erpCardNo = erpCardNo;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getRefundNo() {
        return refundNo;
    }

    public void setRefundNo(String refundNo) {
        this.refundNo = refundNo;
    }

    public Double getRefundMoney() {
        return refundMoney;
    }

    public void setRefundMoney(Double refundMoney) {
        this.refundMoney = refundMoney;
    }

    public String getRedundRemark() {
        return redundRemark;
    }

    public void setRedundRemark(String redundRemark) {
        this.redundRemark = redundRemark;
    }
}

==> connector-service-1.0.0-20190724.130408-35-sources.jar: com/bizvane/connectorservice/entity/common/OrderRefundRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author liuying
 * @date 2018/8/17
 * @description
 */

public class OrderRefundRequestVO extends BaseModel{

    /**
     * 订单编号
     */
    private String orderNo;

    /**
     * 会员卡号(线下会员卡号)
     */
    private String erpCardNo;

    /**
     * 会员id(线下会员id)
     */
    private String erpId;

    /**
     * 审核时间(格式：yyyy-MM-dd HH:mm:ss)
     */
    private Date refundDate;

    /**
     * 退款单号
     */
    private String refundNo;

    /**
     * 退款金额
     */
    private BigDecimal refundMoney;

    /**
     * 退款备注
     */
    private String redundRemark;

    public String getOrderNo() {
        return orderNo;
    }

    public void setOrderNo(String orderNo) {
        this.orderNo = orderNo;
    }

    public String getErpCardNo() {
        return erpCardNo;
    }

    public void setErpCardNo(String erpCardNo) {
        this.erpCardNo = erpCardNo;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public Date getRefundDate() {
        return refundDate;
    }

    public void setRefundDate(Date refundDate) {
        this.refundDate = refundDate;
    }

    public String getRefundNo() {
        return refundNo;
    }

    public void setRefundNo(String refundNo) {
        this.refundNo = refundNo;
    }

    public BigDecimal getRefundMoney() {
        return refundMoney;
    }

    public void setRefundMoney(BigDecimal refundMoney) {
        this.refundMoney = refundMoney;
    }

    public String getRedundRemark() {
        return redundRemark;
    }

    public void setRedundRemark(String redundRemark) {
        this.redundRemark = redundRemark;
    }
}
